<template>
  <div class="app-container">
    <el-dialog
        v-model="dialogVisible"
        title="选择资源"
        width="600px"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
    <div style="margin-bottom: 10px">
      <el-form>
        <el-form-item label="资源名称">
          <el-input style="width: 20%" v-model="data.queryParams.name "></el-input>
          <el-button type="primary" style="margin-left: 30px" @click="getList">查询</el-button>
          <el-button plain @click="reset">重置</el-button>
          <el-button type="primary" @click="openResource">资源上传</el-button>
        </el-form-item>
      </el-form>
    </div>
    <!-- 表格数据 -->
    <el-table v-loading="loading" :data="dataList" :border="true">
      <el-table-column label="序号" type="index" align="center" width="80" />
      <el-table-column label="资源名称" prop="name" align="center"  />
      <el-table-column label="资源类型" prop="resourceType" align="center"  >
        <template #default="scope">
          <span>{{scope.row.resourceType == 1 ? '视频':scope.row.resourceType == 2 ? '音频':'文档'}}</span>
        </template>
      </el-table-column>
      <el-table-column label="上传时间" prop="createTime" align="center"  />
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width" >
        <template #default="scope">
          <el-button link type="primary" @click="choose(scope.row)">选择</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
        v-show="total > 0"
        :total="total"
        v-model:page="queryParams.pageNum"
        v-model:limit="queryParams.pageSize"
        @pagination="getList"
    />
    </el-dialog>
    <resource-dialog ref="resourceRef" @getList="getList"></resource-dialog>
  </div>
</template>

<script setup>
import {getCurrentInstance, onMounted, onUnmounted, reactive, ref, toRefs} from "vue";
import {ElMessage, ElMessageBox} from "element-plus";
import resourceDialog from '@/views/work/onlineEducation/courseManage/courseResource/componets/resourceDialog.vue'
import {checkResourceName, delResource, getResource} from "@/api/onlineEducation/courseResource";
import {checkName} from "@/api/onlineEducation/company";
const { proxy } = getCurrentInstance();
const loading = ref(false);
const emit = defineEmits(["chooseRes"]);
const dialogRef = ref();
const resourceRef = ref()
const data = reactive({
  queryParams: {
    pageNum: 1,
    pageSize: 10,
    name: ''
  },
  total: 0,
  dataList: []
});

const dialogVisible = ref(false);
const { queryParams, total, dataList } = toRefs(data);

onMounted(()=>{

})

onUnmounted(()=>{

})

const openDialog = async () => {
  await getList()
  dialogVisible.value = true;
}

const handleClose = () => {
  dialogVisible.value = false;
}
const getList = async () => {
  loading.value = true
  const res = await getResource(data.queryParams)
  if(res.code == 200){
    data.dataList = res.data.list.map(item => {
      return{
        ...item,
        sizeMB: Number((item.resourceSize /1024 /1024).toFixed(2))+'MB'
      }
    })
    console.log("ddd",data.dataList)
    data.total = res.data.total
  }else{
    ElMessage.warning(res.message)
  }
  loading.value = false
}

const openResource = () => {
  resourceRef.value.openDialog('add',{})
}

const choose = (value) => {
  console.log("co",value)
  emit('chooseRes',value)
  dialogVisible.value = false
  // dialogRef.value.openDialog(type, value);
}
defineExpose({
  openDialog
});


/** 重置新增的表单以及其他数据  */
function reset() {
  data.queryParams = {
    pageNum: 1,
        pageSize: 10,
        name: ''
  }
  getList()
}

</script>
